---
meta:
    title: Browse Earthdata Variables
    description: Browse through the NASA CMR or Giovanni variable catalogs
    toc: false
layout: component
---

```html:preview
<terra-browse-variables></terra-browse-variables>
```

```jsx:react
import TerraBrowseVariables from '@nasa-terra/components/dist/react/browse-variables';

const App = () => <TerraBrowseVariables></TerraBrowseVariables>;
```

## Examples

### Browse the CMR catalog

TODO

### Browse the Giovanni catalog

```html:preview
<terra-browse-variables></terra-browse-variables>
```

[component-metadata:terra-browse-variables]
